# __init__.py
# Copyright 2015 Roger Marsh
# Licence: See LICENCE (BSD licence)

"""Universal Chess Interface (UCI)."""
